@@ -166,6 +166,22 @@ ev_mapping_list_get_list (EvMappingList *mapping_list)
 	return mapping_list ? mapping_list->list : NULL;
 }
 
+/**
+ * ev_mapping_list_remove:
+ * @mapping_list: an #EvMappingList
+ * @mapping: #EvMapping to remove
+ *
+ * Since: 3.14
+ */
+void
+ev_mapping_list_remove (EvMappingList *mapping_list,
+			EvMapping     *mapping)
+{
+	mapping_list->list = g_list_remove (mapping_list->list, mapping);
+        mapping_list->data_destroy_func (mapping->data);
+        g_free (mapping);
+}
+
 guint
 ev_mapping_list_get_page (EvMappingList *mapping_list)
 {
