@@ -334,6 +334,7 @@ ev_sidebar_init (EvSidebar *ev_sidebar)
 	GtkWidget *hbox;
 	GtkWidget *close_button;
 	GtkWidget *select_hbox;
+	GtkWidget *separator;
 	GtkWidget *arrow;
 
 	ev_sidebar->priv = EV_SIDEBAR_GET_PRIVATE (ev_sidebar);
@@ -348,14 +349,16 @@ ev_sidebar_init (EvSidebar *ev_sidebar)
 
 	/* top option menu */
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
-	gtk_widget_set_margin_top (hbox, 2);
-	gtk_widget_set_margin_bottom (hbox, 2);
-	gtk_widget_set_margin_start (hbox, 2);
-	gtk_widget_set_margin_end (hbox, 2);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 2);
 	ev_sidebar->priv->hbox = hbox;
 	gtk_box_pack_start (GTK_BOX (ev_sidebar), hbox, FALSE, FALSE, 0);
 	gtk_widget_show (hbox);
 
+	/* separator */
+	separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
+	gtk_box_pack_start (GTK_BOX (ev_sidebar), separator, FALSE, FALSE, 0);
+	gtk_widget_show (separator);
+
 	ev_sidebar->priv->select_button = gtk_toggle_button_new ();
 	gtk_button_set_relief (GTK_BUTTON (ev_sidebar->priv->select_button), GTK_RELIEF_NONE);
 	g_signal_connect (ev_sidebar->priv->select_button, "button_press_event",
